@@ -1,6 +1,7 @@
 /*
  * ProFTPD - FTP server daemon
- * Copyright (c) 1997, Public Flood Software
+ * Copyright (c) 1997, 1998 Public Flood Software
+ * Copyright (C) 1999, 2000 MacGyver aka Habeeb J. Dihu <macgyver@tos.net>
  *  
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,17 +15,26 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ *
+ * As a special exemption, Public Flood Software/MacGyver aka Habeeb J. Dihu
+ * and other respective copyright holders give permission to link this program
+ * with OpenSSL, and distribute the resulting executable, without including
+ * the source code for OpenSSL in the source distribution.
  */
 
 /* Generic configuration and standard header file includes.
- * $Id: conf.h,v 1.17 1997/12/29 20:21:57 flood Exp $
+ * $Id: conf.h,v 1.11 2001/08/16 20:00:51 flood Exp $
  */
 
 #ifndef __CONF_H
 #define __CONF_H
 
+#include "version.h"
 #include "config.h"
+
+#include "default_paths.h"
+
 /* This is no longer used, autoconf provides us with a top level
  * config.h
  */
@@ -45,6 +55,10 @@
 # include <unistd.h>
 #endif
 
+#ifdef HAVE_SYS_SELECT_H
+# include <sys/select.h>
+#endif
+
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
@@ -56,6 +70,7 @@
 #ifdef HAVE_SYS_WAIT_H
 # include <sys/wait.h>
 #endif
+
 #ifndef WEXITSTATUS
 # define WEXITSTATUS(stat_val) ((unsigned)(stat_val)>>8)
 #endif
@@ -129,26 +144,19 @@ char *strchr(),*strrchr();
 # include <syslog.h>
 #endif
 
-#ifdef HAVE_FNMATCH
-# include <fnmatch.h>
-#endif
-
-#if HAVE_DIRENT_H
+#ifdef HAVE_DIRENT_H
 # include <dirent.h>
 # define NAMLEN(dirent) strlen((dirent)->d_name)
 #else
 # define dirent direct
 # define NAMLEN(dirent) ((dirent)->d_namlen)
-# if HAVE_SYS_NDIR_H
+# ifdef HAVE_SYS_NDIR_H
 #  include <sys/ndir.h>
 # endif
-# if HAVE_SYS_DIR_H
+# ifdef HAVE_SYS_DIR_H
 #  include <sys/dir.h>
 # endif
-# if HAVE_SYS_DIR_H
-#  include <sys/dir.h>
-# endif
-# if HAVE_NDIR_H
+# ifdef HAVE_NDIR_H
 #  include <ndir.h>
 # endif
 #endif
@@ -169,7 +177,7 @@ char *strchr(),*strrchr();
 # include <ctype.h>
 #endif
 
-#ifdef HAVE_FNMATCH_H
+#ifdef HAVE_FNMATCH
 # include <fnmatch.h>
 #endif
 
@@ -177,6 +185,10 @@ char *strchr(),*strrchr();
 # include <utmp.h>
 #endif
 
+#ifdef HAVE_UTMPX_H
+# include <utmpx.h>
+#endif
+
 /* Solaris 2.5 needs sys/termios.h for TIOCNOTTY.  Due to complications
  * with termio.h/termios.h, prefer to include termios.h.  If not found,
  * then try termio.h
@@ -201,18 +213,21 @@ char *strchr(),*strrchr();
 /* See if we have bcopy, if not define them to use the memcpy functions */
 
 #ifndef HAVE_BCOPY
-# define bcopy(s,d,n)	memcpy((s),(d),(n))
+# define bcopy(s,d,n)	memcpy((d),(s),(n))
 # define bzero(d,n)	memset((d),0,(n))
 #endif
 
-/* We use setuid/setgid if not setreuid/setregid */
-
-#ifndef HAVE_SETREUID
-# define setreuid(ruid,euid)		setuid(ruid)
+/* Solaris has __vsnprintf, but no vsnprintf */
+#if ! defined(HAVE_VSNPRINTF) && defined(HAVE___VSNPRINTF)
+# undef vsnprintf
+# define vsnprintf	__vsnprintf
+# define HAVE_VSNPRINTF 1
 #endif
 
-#ifndef HAVE_SETREGID
-# define setregid(rgid,egid)		setgid(rgid)
+#if ! defined(HAVE_SNPRINTF) && defined(HAVE___SNPRINTF)
+# undef snprintf
+# define snprintf	__snprintf
+# define HAVE_SNPRINTF
 #endif
 
 /* If we are BSD, make minor adjustments */
@@ -229,13 +244,44 @@ char *strchr(),*strrchr();
 #define	O_NDELAY	O_NONBLOCK
 #endif
 
+#if defined(HAVE_GETOPT) && defined(AIX3)
+/* AIX 3.2.5 libc exports symbol optopt but is forgotten in includes */
+extern int optopt;
+#endif
+
+/* GNU HURD (and maybe others) do not define MAXPATHLEN */
+#ifndef MAXPATHLEN
+#define MAXPATHLEN      1024
+#endif
+
+/* Necessary for alloca to work */
+#if !defined(__alloca) && !defined(__GNU_LIBRARY__)
+# ifdef __GNUC__
+#  undef alloca
+#  define alloca(n)		__builtin_alloca(n)
+# else /* Not GCC */
+#  ifdef HAVE_ALLOCA_H
+#   include <alloca.h>
+#  else /* No HAVE_ALLOCA_H */
+#   ifndef _AIX
+#    ifdef WINDOWS32
+#     include <malloc.h>
+#    else
+extern char *alloca();
+#    endif /* WINDOWS32 */
+#   endif /* Not _AIX */
+#  endif /* sparc or HAVE_ALLOCA_H */
+# endif /* GCC */
+
+# define __alloca	alloca
+
+#endif
+
 /********************************************************************
  * This is NOT the user configurable section.  Look in options.h
  * for tunable parameters.
  ********************************************************************/
 
-#define VERSION			"1.0.0"
-
 #ifndef __PROFTPD_SUPPORT_LIBRARY
 
 /* This section is only needed for modules and the core source files,
@@ -244,7 +290,7 @@ char *strchr(),*strrchr();
 
 /* Generic typedefs */
 
-typedef struct in_addr in_addr_t;
+typedef struct in_addr p_in_addr_t;
 
 #include "pool.h"
 #include "proftpd.h"
@@ -258,39 +304,17 @@ typedef struct in_addr in_addr_t;
 #include "ident.h"
 #include "ftp.h"
 #include "log.h"
+#include "data.h"
 #include "libsupp.h"
-
-#ifdef NEED_PERSISTANT_PASSWD
-
-void p_setpwent();
-void p_endpwent();
-void p_setgrent();
-void p_endgrent();
-struct passwd *p_getpwent();
-struct group *p_getgrent();
-struct passwd *p_getpwnam(const char *);
-struct passwd *p_getpwuid(uid_t);
-struct group *p_getgrnam(const char *);
-struct group *p_getgrgid(gid_t);
-
-#define setpwent	p_setpwent
-#define endpwent	p_endpwent
-#define setgrent	p_setgrent
-#define endgrent	p_endgrent
-#define getpwent	p_getpwent
-#define getgrent	p_getgrent
-#define getpwnam	p_getpwnam
-#define getpwuid	p_getpwuid
-#define getgrnam	p_getgrnam
-#define getgrgid	p_getgrgid
-
-#else /* NEED_PERSISTANT_PASSWD */
+#include "fs.h"
 
 # ifdef HAVE_SETPASSENT
 #  define setpwent()	setpassent(1)
 # endif /* HAVE_SETPASSENT */
 
-#endif /* NEED_PERSISTANT_PASSWD */
+# ifdef HAVE_SETGROUPENT
+#  define setgrent()	setgroupent(1)
+# endif /* HAVE_SETGROUPENT */
 
 #endif /* __PROFTPD_SUPPORT_LIBRARY */
 
